robotpy-rev
===========

This is a python wrapper around the REV Robotics REVLib. The RobotPy project
is not associated with or endorsed by REV Robotics.

Documentation
=============

* `Installation <http://robotpy.readthedocs.io/en/stable/install/rev.html>`_
* `Python API Documentation <http://robotpy.readthedocs.io/projects/rev/en/stable/api.html>`_
* `REVLib documentation <https://docs.revrobotics.com/docs/first-robotics-competition>`_

License
=======

RobotPy specific bits are available under a BSD-3-Clause license. The REV
specific pieces are available under a BSD license.

Author
======

Dustin Spicuzza (dustin@virtualroadside.com)
